/*
-------------------------------------------------------------------------------
Name:	TB_GroupAndMerge.js

Description: Group and Merge takes the art on multiple layers, converts them into groups, and merges them together, all the while getting around the flaw in the software
that eliminates groups when using Merge Layers.

Usage:	Select a panel, select your layers, run script, choose a new name for the layer, and watch your art get merged together. This only works for one panel at a time. If anything
other than one panel is selected, the script will abort.

Author:	Corey Barnes

Created: 2019/7/11

Updated: 2019/11/3

Version: 1.0.0

Contact Info: Report bugs to livingfruitvirus@gmail.com

Twitter:
http://twitter.com/myanimewaifu

-------------------------------------------------------------------------------
*/



function GroupAndMerge() {

	var selMgr = new SelectionManager(); 
	var layMgr = new LayerManager();
   
	var panelSel = selMgr.getPanelSelection();
	if (panelSel.length != 1) {
 
	 MessageBox.information("Please select only one panel.");
	 return;
	 }
 
	 // Retrieve selection
 
	 var layerSel = selMgr.getLayerSelection();  // [{index: int, layerIndex: int, name: String, panelId: String}, ...]
 
	 scene.beginUndoRedoAccum("Group and Merge");
 
	 // Step 0: Step through each panel.
	 for (var j = 0; j < panelSel.length; j++) { // Begin the indexing of panels
 
		 // Step 1: Get layer selection for the current panel
		 var panelLayerSel = new Array(0);
		 var thisPanel = panelSel[j]; //string, panel hash
		 selMgr.setCurrentPanel(thisPanel); // Moves the playhead to the next panel in the index
 
		 // for each layer in the selection, push only layers that match the current panel into panelLayerSel
		 for ( var i = 0; i < layerSel.length ; i++ ) 
		 {			
			 var currentLayer = {index: layerSel[i].index, name: layerSel[i].name, panelId: thisPanel};
			 panelLayerSel.push(currentLayer);
		 }
 
			 // MessageBox.information(JSON.stringify(panelLayerSel));
 
 
		 // Step 1: Group art.
		 for (var i = 0; i < panelLayerSel.length; i++) {
 
			 selMgr.clearSelection();
			 var tempSel = [];
			 tempSel.push(panelLayerSel[i]);
 
			 selMgr.setLayerSelection(tempSel); // Selects the layer
 
			 // Select Art and Group it
			 Action.perform('selectAll()');
			 Action.perform('onActionGroup()');
 
		 }
 
		 // Step 2: Reverse layer selection order so the bottom layer goes first.
 
		 selMgr.setLayerSelection(panelLayerSel);
		 cpLayers = selMgr.getLayerSelection();
 
		 cpLayers.reverse();
 
		 // Step 3: Begin the copy/pasting of groups onto one layer.
 
		 for (var i = 0; i < cpLayers.length; i++) {
 
			 selMgr.clearSelection();
			 var tempSel = [];
			 tempSel.push(cpLayers[i]);
 
			 selMgr.setLayerSelection(tempSel); // Selects the layer
 
			 if (i > 0) {
				 Action.perform('paste()');
				 }
			 Action.perform('selectAll()');
			 Action.perform('copy()');
 
		 }
 
		 // Rename Layer
		 var renameDialog = new Dialog;
		   var textInput = new LineEdit;
 
		   renameDialog.title = "New Layer Name";
		   renameDialog.width = 200;
		   renameDialog.add(textInput);
 
		   var rd = renameDialog.exec();
 
		   // If dialog cancelled, return
		   if (!rd) {
			 return;
		   }
 
		 var last = cpLayers[cpLayers.length - 1];
		 var theIndex = last.layerIndex;
		 layMgr.renameLayer(thisPanel, theIndex, textInput.text);
 
		 // Step 4: Delete every layer that is not the last.
 
		 cpLayers.pop();
 
		 selMgr.setLayerSelection(cpLayers);
		 Action.perform('onActionDeleteLayer()');
	 }
 
	 scene.endUndoRedoAccum();
	 // End script
 
 }
 