/*
-------------------------------------------------------------------------------
Name:	TB_LayerReorderer.js

Description: This script contains functions that allow the user to move a common
layer from a point in any panel next to another common layer within the same panels.
Any panel missing these layers will be skipped over.

Usage:	Run script, pick from selection.

Author:	Corey Barnes and Karl Olson

Created: 2020/7/30

Version: 1.0.0

Feedback/Bugs contact: livingfruitvirus@gmail.com

Twitter:
Corey - http://twitter.com/myanimewaifu
Karl - http://twitter.com/karlrolson
-------------------------------------------------------------------------------
*/

function LayerReorderer() {
  var selMgr = new SelectionManager();
  var layMgr = new LayerManager();

  var panelSel = selMgr.getPanelSelection();
  if (panelSel.length <= 0) return;

  var layerNames = new Array(0);
  for (var i = 0; i < panelSel.length; i++) {
    var panelId = panelSel[i];
    var numberOfLayers = layMgr.numberOfLayers(panelId);

    for (var j = 0; j < numberOfLayers; ++j) {
      var layerName = layMgr.layerName(panelId, j);

      if (layerNames.indexOf(layerName) == -1) layerNames.push(layerName);
    }
  }

  var startDialog = new Dialog();
  startDialog.title = "Layer Reorderer";

  var startLayerGroup = new GroupBox();
  startLayerGroup.title = "Choose layer to move.";
  var radioButtonsArray = new Array(0);

  for (var ie = 0; ie < layerNames.length; ++ie) {
    var c = new RadioButton();
    c.text = layerNames[ie];
    radioButtonsArray.push(c);
    startLayerGroup.add(c);
  }

  startDialog.add(startLayerGroup);

  var rca = startDialog.exec();

  if (!rca) {
    return;
  }

  var startLayer;
  for (var i = 0; i < layerNames.length; ++i) {
    var r = radioButtonsArray[i];
    if (r.checked == true) {
      startLayer = radioButtonsArray[i].text;
      break;
    }
  }

  if (startLayer == null) {
    MessageBox.information("Please select a layer.");
    return;
  }

  var finishDialog = new Dialog();
  finishDialog.title = "Layer Reorderer";

  var finishLayerGroup = new GroupBox();
  finishLayerGroup.title = "Choose where to move your selection next to.";
  radioButtonsArray = new Array(0);

  for (var ie = 0; ie < layerNames.length; ++ie) {
    if (layerNames[ie] != startLayer) {
      var c = new RadioButton();
      c.text = layerNames[ie];
      radioButtonsArray.push(c);
      finishLayerGroup.add(c);
    }
  }

  finishDialog.add(finishLayerGroup);

  var underOverGroup = new GroupBox();
  underOverGroup.title = "Place layer selection above or below?";
  var underOverRadioButtonsArray = new Array(0);
  var positions = ["Above", "Below"];
  for (var i = 0; i < positions.length; i++) {
    var c = new RadioButton();
    c.text = positions[i];
    underOverRadioButtonsArray.push(c);
    underOverGroup.add(c);
  }

  finishDialog.add(underOverGroup);

  rca = finishDialog.exec();

  if (!rca) {
    return;
  }

  var finishLayer;
  for (var i = 0; i < layerNames.length - 1; ++i) {
    var r = radioButtonsArray[i];
    if (r.checked == true) {
      finishLayer = radioButtonsArray[i].text;
      break;
    }
  }

  if (finishLayer == null) {
    MessageBox.information("Please select a layer.");
    return;
  }

  var moveLocation;
  for (var i = 0; i < positions.length; i++) {
    var r = underOverRadioButtonsArray[i];
    if (r.checked == true) {
      moveLocation = underOverRadioButtonsArray[i].text;
      break;
    }
  }

  if (moveLocation == null) {
    MessageBox.information("Please select a location.");
    return;
  }

  // RUN SCRIPT

  scene.beginUndoRedoAccum("Layer Reorderer");

  for (var i = 0; i < panelSel.length; i++) {
    var thisPanel = panelSel[i];
    selMgr.setCurrentPanel(thisPanel);
    var numLayers = layMgr.numberOfLayers(thisPanel);
    var startIndex = null;
    var finishIndex = null;

    for (var j = 0; j < numLayers; j++) {
      var layerPicker = layMgr.layerName(thisPanel, j);

      if (layerPicker == startLayer) {
        startIndex = j;
      } else if (layerPicker == finishLayer) {
        finishIndex = j;
      }
    }

    if (startIndex !== null && finishIndex !== null) {
      var moveNumber = startIndex - finishIndex;

      var selectedLayer = new Array(0);
      selectedLayer[0] = {
        layerIndex: startIndex,
        name: startLayer,
        panelId: thisPanel,
      };
      selMgr.setLayerSelection(selectedLayer);

      var moveLayerFunction;
      if (moveNumber > 0) {
        moveLayerFunction = function () {
          Action.perform("onActionMoveTabUp()");
        };
      } else {
        moveLayerFunction = function () {
          Action.perform("onActionMoveTabDown()");
        };
      }

      if (moveNumber < 0 && moveLocation == positions[0]) {
        moveNumber++;
      }

      if (moveNumber > 0 && moveLocation == positions[1]) {
        moveNumber--;
      }

      moveNumber = Math.abs(moveNumber);

      for (var f = 0; f < moveNumber; f++) {
        moveLayerFunction();
      }
    }
  }
  scene.endUndoRedoAccum();
}
