/*
-------------------------------------------------------------------------------

Name: TB_PasteCycleAcrossPanels.js

Description: This script takes a series of layers copied on one panel and cycles them through as many panels as the user wishes.

Usage: Copy layers from panel, select panels, and run script. Script will not work if no layers are in the copy clipboard.

Author: Corey Barnes and Karl Olson

Created: 2018/12/12

Updated: 2018

Version: 1.0.0

Social Media Info:
Corey on Twitter - http://twitter.com/myanimewaifu
Karl on Twitter - http://twitter.com/karlrolson

Contact Email: livingfruitvirus@gmail.com

-------------------------------------------------------------------------------
*/

function TB_PasteCycleAcrossPanels() { // BEGIN FUNCTION. By this point, the layers should be in the clipboard.
    MessageLog.trace('Paste Cycle Across Panels--------- ');
  
    var selMgr = new SelectionManager();
    var layMgr = new LayerManager();
  
    var panelSel = selMgr.getPanelSelection();
  
    // ------ Begin running the script ------
  
    if (panelSel.length > 1) {
      scene.beginUndoRedoAccum('Paste Cycle Across Panels');
  
      var b =  layMgr.numberOfLayers(panelSel[0]);
  
      // Begin pasting the cycling layers over the panel selection
      for (var i = 0; i < panelSel.length; i++)
      {
        var thisPanel = panelSel[i];      
        selMgr.setCurrentPanel(thisPanel); 
        Action.perform('onActionPasteLayers()');
      }
  
      var a =  layMgr.numberOfLayers(panelSel[0]); 
      var c = a - b;
      
      var layersToCycle = new Array(0);
      for (i = 0; i < c; i++)
          {
              layersToCycle.push(i);
          }
          c--; 
      var doNotDelete = c + 1;
      var cycleloop = 0; 
  
      for (var il = 0; il < panelSel.length; il++) { // PANEL LOOP
         
      if (cycleloop > c) {
          cycleloop = 0;
      } 
      
          var dnd = doNotDelete;
          var currentPanel = panelSel[il];
          var cL = cycleloop; 
  
          for (var ip = 0; ip < dnd; ip++) { // LAYER LOOP
  
              if (cL != layersToCycle[ip]) {
                  layMgr.deleteLayer(currentPanel, ip); // This code kills every layer that isn't the one to cycle.
                  ip--;
                  dnd--;
                  cL--;
                  }
          } // END OF LAYER LOOP
      cycleloop++;
  
        } // END OF PANEL LOOP
  
      scene.endUndoRedoAccum();
  
      // Prepare report.
      MessageBox.information("Cycle pasted.");
    } else {
      MessageBox.information("Not enough panels selected.");
    }
  }
  